@@ -8,15 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pepperize/cdk-private-bucket",
-    "0.0.13",
+    "0.0.14",
     __name__[0:-6],
-    "cdk-private-bucket@0.0.13.jsii.tgz",
+    "cdk-private-bucket@0.0.14.jsii.tgz",
 )
 
 __all__ = [
